#ifndef SokoPref_h
#define SokoPref_h
//-----------------------------------------------------------------------------
// SokoPref.h
//
//	User preferences module for SokoSave.
//
// Copyright (c), 1997,2001, Eric Sunshine <sunshine@sunshineco.com>
// Copyright (c), 1997, Paul McCarthy <zarnuk@high-speed-software.com>
// All rights reserved.
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
// $Id: SokoPref.h,v 1.4 2001/12/23 17:54:28 sunshine Exp $
// $Log: SokoPref.h,v $
// Revision 1.4  2001/12/23 17:54:28  sunshine
// v15
// -*- Extracted core game logic out of GUI code and generalized it so that
//     the same core code can be used by any platform.  Logic from
//     SokoBoard.m now resides in SokoPuzzle.c, etc.
//
// -*- Rewrote the NextStep port so that it utilizes the new "sokocore" game
//     library rather than implementing that logic directly.
//
// -*- Replaced the terminology "maze" with "puzzle" throughout the project,
//     including source code, documentation, and all user-visible UI
//     elements.  The only remaining place where "maze" is still used is in
//     the file extension ".sokomaze".  I haven't decided what, if anything,
//     to do about that, yet.
//
// -*- Added the new pseudo-variable $(SokoUser) which points at the user's
//     "personal" file space.  This is where user-specific SokoSave files are
//     stored by default.  This variable complements the existing $(SokoSave)
//     variable.
//
// -*- Renamed soko_collapse() to soko_collapse_path().  Renamed
//     soko_expand() to soko_expand_path().
//
// -*- The path setting functions in SokoFile now invoke soko_collapse_path()
//     on all set operations.  This ensures that all paths displayed on the
//     preferences panel are properly collapsed, and removes the onus of this
//     task from the UI code.  Previously, soko_collapse_path() was only
//     called by the UI code for the puzzle path.
//
// -*- Added soko_normalize_path() and soko_denormalize_path() to SokoUtil.
//     All path manipulation functions now utilize these functions in order
//     to ensure correctness of path parsing and composition on all
//     platforms.
//
// -*- Added soko_set_puzzle_directory(), soko_set_save_directory(), and
//     soko_set_score_file() to SokoFile in order to complement the existing
//     "get" functions and to centralize control over these settings.
//
// -*- Added soko_get_default_puzzle_directory(),
//     get_default_save_directory(), and soko_get_default_score_file() to
//     SokoFile.  These functions return values appropriate for the
//     corresponding fields on the Preferences panel of each port when the
//     "Defaults" button is pressed.
//
// -*- Added SokoSetting implementation which provides a platform-independent
//     API for accessing user settings and well-known paths, such as
//     $(SokoSave) and $(SokoUser).
//
// -*- For safety, user defaults (including score panel column order and
//     widths) are now committed immediately, rather than at termination
//     time.
//
// -*- Added SokoWindow and SokoPanel which are subclasses of Window and
//     Panel, respectively.  All windows and panels throughout the
//     application are now instances of these classes.  Although these
//     classes currently implement no extra functionality, they provide
//     convenient hooks for the addition of new functionality in the future,
//     if needed.
//
// -*- Renamed "window" instance variable to "panel" for all classes and nibs
//     in which a panel is actually used (everything but SokoBoard, in fact).
//
// Revision 1.3  2001/08/19 10:00:35  sunshine
// v11
// -*- Converted from Objective-C++ to pure Objective-C.  Changed file
//     extensions from .M to .m, and .cc to .c.  This change makes it easier
//     to support both GNUstep and MacOS/X, neither of which feature an
//     Objective-C++ compiler (though MacOS/X will reportedly support
//     Objective-C++ at some point in the future).
//
// -*- Eliminated all inclusions of <appkit/appkit.h> throughout the project;
//     replaced with inclusion of individual header files.
//
// -*- Upgraded formatting of source and header files which I had not updated
//     in the last version.  Added explicit (id) in several places which had
//     not previously been updated.
//
// -*- Renamed the following functions in order to avoid potential symbolic
//     collisions in the target environment:
//
//     basename --> soko_basename
//     collapse --> soko_collapse
//     directoryPart --> soko_directory_part
//     ends_with --> soko_ends_with
//     expand --> soko_expand
//     filenamePart --> soko_filename_part
//     getFactoryScoresFile --> soko_get_factory_scores_file
//     getMazeDirectory --> soko_get_maze_directory
//     getMazeExtension --> soko_get_maze_extension
//     getSaveDirectory --> soko_get_save_directory
//     getSaveExtension --> soko_get_save_extension
//     getScoresFile --> soko_get_scores_file
//     load_nib --> soko_load_nib
//     mazeNameForLevel --> soko_maze_name_for_level
//     mkdirs --> soko_mkdirs
//     runLengthDecodeChar --> soko_run_length_decode_char
//     runLengthDecodeString --> soko_run_length_decode_string
//     runLengthEncodeChar --> soko_run_length_encode_char
//     runLengthEncodeString --> soko_run_length_encode_string
//     saveFileNameForMazeName --> soko_save_filename_for_maze_name
//     starts_with --> soko_starts_with
//     strdup --> soko_strdup
//-----------------------------------------------------------------------------
#import <objc/Object.h>
#import "SokoSetting.h"
@class Button, SokoPanel, TextField;

@interface SokoPref : Object
    {
    TextField* puzzleDirField;
    TextField* saveDirField;
    TextField* scoresFileField;
    TextField* levelField;
    Button* autoSaveSwitch;
    SokoPanel* panel;
    SokoSetting setting;
    }

+ (void)startup;
+ (void)shutdown;
+ (void)launch;
+ (int)getNextLevel;
+ (void)setNextLevel:(int)level;

@end

#endif // SokoPref_h
